@@ -12,10 +12,13 @@ header = {
     'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; WOW64; rv:23.0) Gecko/20100101 Firefox/23.0'}
 
 
+flags = ['|','/','-','\\']
+
+
 def progress(done,size,total):
     pre =100.0 * done * size / total
     down = done * size
-    print2.print2.message('%0.2f%% @ %0.2fKB/%0.2fKB\r'%(pre,down/1024,total/1024))
+    print2.print2.message('>%s %0.2f%% [%s%s]  @ %0.2fKB/%0.2fKB\r'%(flags[int(pre)%4],pre,'#'*int(pre/10),'.'*int(10-pre/10),down/1024,total/1024))
     if pre > 100:
         print2.print2.message('\r')
 
